==> haskell-decimal-0.5.2-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-BNb9YCHVG2C60ze0TOBA5o
key:                  Decimal-0.5.2-BNb9YCHVG2C60ze0TOBA5o
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  ce8210a88678b42486949bb00e5b439a
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-BNb9YCHVG2C60ze0TOBA5o
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-decimal-0.5.2-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-decimal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-JecesaLH4RB2M9nkzEdh9r
key:                  Decimal-0.5.2-JecesaLH4RB2M9nkzEdh9r
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  29249b6b18fe31c8e6672a61e0e55503
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-decimal
hs-libraries:         HSDecimal-0.5.2-JecesaLH4RB2M9nkzEdh9r
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
